@@ -1,22 +1,24 @@
+from .lazy.has_lazy_print_transform_info import HasLazyPrintTransformInfo
 from ..batch.base import BatchOperator, BatchOperatorWrapper
+from ..common.types.bases.params import Params
+from ..common.types.bases.with_params import WithParams
 from ..py4j_util import get_java_gateway, get_java_class
 from ..stream.base import StreamOperatorWrapper
-from ..with_params import WithParams
 
 
-class Transformer(WithParams):
+class Transformer(WithParams, HasLazyPrintTransformInfo):
     def get_j_obj(self):
-        return self.op
+        return self.j_transformer
 
-    def __init__(self, op=None, *args, **kwargs):
+    def __init__(self, j_transformer=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
         name = kwargs.pop('name', None)
         clsName = kwargs.pop('CLS_NAME', None)
         self.opType = kwargs.pop('OP_TYPE', 'FUNCTION')
-        if op is None:
-            self.op = get_java_gateway().jvm.__getattr__(clsName)()
+        if j_transformer is None:
+            self.j_transformer = get_java_gateway().jvm.__getattr__(clsName)()
         else:
-            self.op = op
+            self.j_transformer = j_transformer
 
     def transform(self, input):
         if isinstance(input, BatchOperator):
@@ -29,14 +31,13 @@ class Transformer(WithParams):
 
 class TransformerWrapper(Transformer):
     def __init__(self, j_transformer):
-        super(TransformerWrapper, self).__init__()
-        self.op = j_transformer
+        super(TransformerWrapper, self).__init__(j_transformer=j_transformer)
 
 
 class Model(Transformer):
     def __init__(self, model, *args, **kwargs):
         self.model = model
-        super(Model, self).__init__(op=model, *args, **kwargs)
+        super(Model, self).__init__(j_transformer=model, *args, **kwargs)
 
     def get_j_obj(self):
         return self.model
@@ -59,10 +60,28 @@ class PipelineModel(Model):
         else:
             operator = path_or_operator
             pipeline_model = _j_pipeline_model.load(operator.get_j_obj())
+
+        LAZY_PRINT_TRANSFORM_DATA_ENABLED = "lazyPrintTransformDataEnabled"
+        LAZY_PRINT_TRANSFORM_DATA_TITLE = "lazyPrintTransformDataTitle"
+        LAZY_PRINT_TRANSFORM_DATA_NUM = "lazyPrintTransformDataNum"
+        LAZY_PRINT_TRANSFORM_STAT_ENABLED = "lazyPrintTransformStatEnabled"
+        LAZY_PRINT_TRANSFORM_STAT_TITLE = "lazyPrintTransformStatTitle"
+
+        for j_transformer in pipeline_model.getTransformers():
+            params = Params.fromJson(j_transformer.getParams().toJson())
+            transformer = TransformerWrapper(j_transformer)
+
+            if params.get(LAZY_PRINT_TRANSFORM_STAT_ENABLED, False):
+                transformer.enableLazyPrintTransformStat(params.get(LAZY_PRINT_TRANSFORM_STAT_TITLE))
+            if params.get(LAZY_PRINT_TRANSFORM_DATA_ENABLED, False):
+                transformer.enableLazyPrintTransformData(
+                    params.get(LAZY_PRINT_TRANSFORM_DATA_NUM),
+                    params.get(LAZY_PRINT_TRANSFORM_DATA_TITLE))
+
         return PipelineModel(pipeline_model)
 
 
-class Estimator(WithParams):
+class Estimator(WithParams, HasLazyPrintTransformInfo):
     def get_j_obj(self):
         return self.op
 
@@ -105,7 +124,7 @@ class Pipeline(Estimator):
         num = len(stages)
         args = get_java_gateway().new_array(j_pipeline_stage_base, num)
         for i, stage in enumerate(stages):
-            args[i] = stage.op
+            args[i] = stage.get_j_obj()
         self.op = j_pipeline(args)
 
     def add(self, *args):
