@@ -2,9 +2,136 @@
 # -*- coding: utf-8 -*-
 
 from ..base import Estimator, Transformer, Model, TuningEvaluator, BaseTuningModel
+from ..lazy.has_lazy_print_model_info import HasLazyPrintModelInfo
+from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 
 
-class StandardScaler(Estimator):
+class Segment(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Segment'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Segment, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setUserDefinedDict(self, val):
+        return self._add_param('userDefinedDict', val)
+
+
+class Select(Transformer):
+    CLS_NAME = 'com.alibaba.alink.pipeline.sql.Select'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Select, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+
+class Softmax(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.Softmax'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Softmax, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setL1(self, val):
+        return self._add_param('l1', val)
+
+    def setL2(self, val):
+        return self._add_param('l2', val)
+
+    def setMaxIter(self, val):
+        return self._add_param('maxIter', val)
+
+    def setOptimMethod(self, val):
+        return self._add_param('optimMethod', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStandardization(self, val):
+        return self._add_param('standardization', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWithIntercept(self, val):
+        return self._add_param('withIntercept', val)
+
+
+class SoftmaxModel(Model):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.SoftmaxModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SoftmaxModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class StandardScaler(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.StandardScaler'
     OP_TYPE = 'FUNCTION'
 
@@ -17,18 +144,18 @@ class StandardScaler(Estimator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
     def setWithMean(self, val):
         return self._add_param('withMean', val)
 
     def setWithStd(self, val):
         return self._add_param('withStd', val)
 
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class StandardScalerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.StandardScalerModel'
@@ -40,12 +167,12 @@ class StandardScalerModel(Model):
         super(StandardScalerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
 
 class StopWordsRemover(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.StopWordsRemover'
@@ -60,20 +187,20 @@ class StopWordsRemover(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
     def setCaseSensitive(self, val):
         return self._add_param('caseSensitive', val)
 
-    def setStopWords(self, val):
-        return self._add_param('stopWords', val)
-
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setStopWords(self, val):
+        return self._add_param('stopWords', val)
 
 
 class StringIndexer(Estimator):
@@ -89,23 +216,23 @@ class StringIndexer(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelName(self, val):
-        return self._add_param('modelName', val)
-
-    def setStringOrderType(self, val):
-        return self._add_param('stringOrderType', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
+    def setModelName(self, val):
+        return self._add_param('modelName', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStringOrderType(self, val):
+        return self._add_param('stringOrderType', val)
 
 
 class StringIndexerModel(Model):
@@ -118,8 +245,11 @@ class StringIndexerModel(Model):
         super(StringIndexerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
@@ -127,8 +257,8 @@ class StringIndexerModel(Model):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
 
 class Tokenizer(Transformer):
@@ -144,15 +274,15 @@ class Tokenizer(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorAssembler(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorAssembler'
@@ -164,20 +294,20 @@ class VectorAssembler(Transformer):
         super(VectorAssembler, self).__init__(*args, **kwargs)
         pass
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setHandleInvalidMethod(self, val):
         return self._add_param('handleInvalidMethod', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
 
 class VectorElementwiseProduct(Transformer):
@@ -196,15 +326,15 @@ class VectorElementwiseProduct(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorImputer(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorImputer'
@@ -219,8 +349,8 @@ class VectorImputer(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setStrategy(self, val):
-        return self._add_param('strategy', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setFillValue(self, val):
         return self._add_param('fillValue', val)
@@ -228,8 +358,8 @@ class VectorImputer(Estimator):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setStrategy(self, val):
+        return self._add_param('strategy', val)
 
 
 class VectorImputerModel(Model):
@@ -242,12 +372,12 @@ class VectorImputerModel(Model):
         super(VectorImputerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
 
 class VectorInteraction(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorInteraction'
@@ -259,20 +389,20 @@ class VectorInteraction(Transformer):
         super(VectorInteraction, self).__init__(*args, **kwargs)
         pass
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
 
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
-class VectorMaxAbsScaler(Estimator):
+
+class VectorMaxAbsScaler(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMaxAbsScaler'
     OP_TYPE = 'FUNCTION'
 
@@ -285,12 +415,12 @@ class VectorMaxAbsScaler(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
 
 class VectorMaxAbsScalerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMaxAbsScalerModel'
@@ -302,14 +432,14 @@ class VectorMaxAbsScalerModel(Model):
         super(VectorMaxAbsScalerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
 
-class VectorMinMaxScaler(Estimator):
+
+class VectorMinMaxScaler(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMinMaxScaler'
     OP_TYPE = 'FUNCTION'
 
@@ -322,18 +452,18 @@ class VectorMinMaxScaler(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setMin(self, val):
-        return self._add_param('min', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setMax(self, val):
         return self._add_param('max', val)
 
+    def setMin(self, val):
+        return self._add_param('min', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorMinMaxScalerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMinMaxScalerModel'
@@ -345,12 +475,12 @@ class VectorMinMaxScalerModel(Model):
         super(VectorMinMaxScalerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
 
 class VectorNormalizer(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorNormalizer'
@@ -365,18 +495,18 @@ class VectorNormalizer(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setP(self, val):
-        return self._add_param('p', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
+    def setP(self, val):
+        return self._add_param('p', val)
+
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorPolynomialExpand(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorPolynomialExpand'
@@ -391,18 +521,18 @@ class VectorPolynomialExpand(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setDegree(self, val):
+        return self._add_param('degree', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setDegree(self, val):
-        return self._add_param('degree', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorSizeHint(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorSizeHint'
@@ -420,18 +550,18 @@ class VectorSizeHint(Transformer):
     def setSize(self, val):
         return self._add_param('size', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setHandleInvalidMethod(self, val):
-        return self._add_param('handleInvalidMethod', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorSlicer(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorSlicer'
@@ -446,20 +576,20 @@ class VectorSlicer(Transformer):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setIndices(self, val):
+        return self._add_param('indices', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setIndices(self, val):
-        return self._add_param('indices', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class VectorStandardScaler(Estimator):
+class VectorStandardScaler(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorStandardScaler'
     OP_TYPE = 'FUNCTION'
 
@@ -472,18 +602,18 @@ class VectorStandardScaler(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
     def setWithMean(self, val):
         return self._add_param('withMean', val)
 
     def setWithStd(self, val):
         return self._add_param('withStd', val)
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorStandardScalerModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorStandardScalerModel'
@@ -495,12 +625,12 @@ class VectorStandardScalerModel(Model):
         super(VectorStandardScalerModel, self).__init__(*args, **kwargs)
         pass
 
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
     def setMLEnvironmentId(self, val):
         return self._add_param('MLEnvironmentId', val)
 
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
 
 class VectorToColumns(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToColumns'
@@ -518,38 +648,15 @@ class VectorToColumns(Transformer):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
-
-class VectorToColumns(Transformer):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorToColumns'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToColumns, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
-
 
 class VectorToCsv(Transformer):
     CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToCsv'
@@ -570,20 +677,20 @@ class VectorToCsv(Transformer):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setCsvFieldDelimiter(self, val):
         return self._add_param('csvFieldDelimiter', val)
 
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setQuoteChar(self, val):
+        return self._add_param('quoteChar', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
 
 class VectorToJson(Transformer):
@@ -602,14 +709,14 @@ class VectorToJson(Transformer):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setHandleInvalid(self, val):
         return self._add_param('handleInvalid', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
 
 class VectorToKv(Transformer):
@@ -628,8 +735,11 @@ class VectorToKv(Transformer):
     def setVectorCol(self, val):
         return self._add_param('vectorCol', val)
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
 
     def setKvColDelimiter(self, val):
         return self._add_param('kvColDelimiter', val)
@@ -637,11 +747,8 @@ class VectorToKv(Transformer):
     def setKvValDelimiter(self, val):
         return self._add_param('kvValDelimiter', val)
 
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
 
 
 class Word2Vec(Estimator):
@@ -657,29 +764,17 @@ class Word2Vec(Estimator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setAlpha(self, val):
         return self._add_param('alpha', val)
 
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
     def setMinCount(self, val):
         return self._add_param('minCount', val)
 
-    def setRandomWindow(self, val):
-        return self._add_param('randomWindow', val)
-
-    def setWindow(self, val):
-        return self._add_param('window', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
 
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
@@ -687,22 +782,37 @@ class Word2Vec(Estimator):
     def setPredMethod(self, val):
         return self._add_param('predMethod', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setRandomWindow(self, val):
+        return self._add_param('randomWindow', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+    def setWindow(self, val):
+        return self._add_param('window', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
 
 
-class _Word2VecModel(Model):
+class Word2VecModel(Model):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Word2VecModel'
     OP_TYPE = 'FUNCTION'
 
     def __init__(self, *args, **kwargs):
         kwargs['CLS_NAME'] = self.CLS_NAME
         kwargs['OP_TYPE'] = self.OP_TYPE
-        super(_Word2VecModel, self).__init__(*args, **kwargs)
+        super(Word2VecModel, self).__init__(*args, **kwargs)
         pass
 
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setMLEnvironmentId(self, val):
+        return self._add_param('MLEnvironmentId', val)
 
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
@@ -710,6 +820,9 @@ class _Word2VecModel(Model):
     def setPredMethod(self, val):
         return self._add_param('predMethod', val)
 
-    def setMLEnvironmentId(self, val):
-        return self._add_param('MLEnvironmentId', val)
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWordDelimiter(self, val):
+        return self._add_param('wordDelimiter', val)
 
