@@ -1,6 +1,6 @@
-from ...converters import py_list_to_j_array
+from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
+from ...common.types.conversion.java_method_call import call_java_method
 from ...py4j_util import get_java_class
-from ...with_params import JavaObjectWrapper
 
 
 class ParamGrid(JavaObjectWrapper):
@@ -8,8 +8,7 @@ class ParamGrid(JavaObjectWrapper):
         return self.j_param_dist
 
     def __init__(self):
-        j_param_dist_cls = get_java_class("com.alibaba.alink.pipeline.tuning.ParamGrid")
-        self.j_param_dist = j_param_dist_cls()
+        self.j_param_dist = get_java_class("com.alibaba.alink.pipeline.tuning.ParamGrid")()
         self.items = []
         pass
 
@@ -18,9 +17,7 @@ class ParamGrid(JavaObjectWrapper):
             raise Exception("at least 1 item should be provided in addGrid")
         if isinstance(args[0], (list, tuple,)):
             args = args[0]
-        # TODO: change the way to get info
-        j_args = py_list_to_j_array(get_java_class("Object"), len(args), args)
-        self.get_j_obj().addGrid(stage.get_j_obj(), stage.get_j_obj().__getattr__(info), j_args)
+        call_java_method(self.get_j_obj().addGrid, stage, info, args)
         self.items.append((stage, info, args))
         return self
 
