@@ -1,8 +1,9 @@
 import base64
 import json
 
-from pyalink.alink.py4j_util import get_java_class
-from pyalink.alink.utils import ensure_unicode, has_pyflink
+from ..common.utils.encoding import ensure_unicode
+from ..common.utils.packages import has_pyflink
+from ..py4j_util import get_java_class
 
 
 def _to_dill_base64(v):
@@ -55,8 +56,8 @@ def register_pyflink_function(name, func, env_type):
     if has_pyflink():
         from pyflink.table.udf import UserDefinedFunctionWrapper
     else:
-        from pyalink.alink.udf.udf import UserDefinedFunctionWrapper
-    from pyalink.alink.udf.udtf import UserDefinedTableFunctionWrapper
+        from .udf import UserDefinedFunctionWrapper
+    from .udtf import UserDefinedTableFunctionWrapper
 
     if isinstance(func, UserDefinedFunctionWrapper):
         result_type = _to_flink_type_string(func._result_type)
@@ -120,7 +121,7 @@ def do_set_op_udf(op, func):
     if has_pyflink():
         from pyflink.table.udf import UserDefinedFunctionWrapper
     else:
-        from pyalink.alink.udf.udf import UserDefinedFunctionWrapper
+        from .udf import UserDefinedFunctionWrapper
     if isinstance(func, UserDefinedFunctionWrapper):
         result_type = _to_flink_type_string(func._result_type)
         op.setResultType(result_type) \
@@ -136,7 +137,7 @@ def do_set_op_udtf(op, func):
         op.setClassObjectType("CLOUDPICKLE_BASE64")
         return op
 
-    from pyalink.alink.udf.udtf import UserDefinedTableFunctionWrapper
+    from .udtf import UserDefinedTableFunctionWrapper
     if isinstance(func, UserDefinedTableFunctionWrapper):
         result_types = list(map(_to_flink_type_string, func._result_types))
         op.setResultTypes(result_types) \
